@@ -336,7 +336,7 @@ class Locale(object):
         ('ru_RU', {
             'name': 'Русский (Россия)',
             'locale': 'ru_RU.utf8',
-            'keymap': '-u ruwin_cplk-utf8',
+            'keymap': '-u ruwin_cplk-UTF-8',
             'timezone': 'Europe/Moscow',
             'dumpkeys_charset': '',
             'consolefont': 'ter-v14n',
@@ -386,7 +386,7 @@ class Locale(object):
         ('fi_FI', {
             'name': 'Suomi (Suomi)',
             'locale': 'fi_FI.utf8',
-            'keymap': 'fi-latin9',
+            'keymap': 'fi-latin1',
             'timezone': 'Europe/Helsinki',
             'dumpkeys_charset': '',
             'consolefont': 'ter-v14n',
